<template>
  <van-popup v-model="showCalling" position="bottom" :style="{ height: '100%' }" @open="onOpen" @close="handleLeave">
    <van-nav-bar class="call-nav-bar" @click-right="onClose">
      <template #left>
        <van-icon name="volume" />
      </template>
      <template #title>
        <div class="title">
          <span class="name">{{ title }}</span>
          <span class="timer">{{ currentDatetime }}</span>
        </div>
      </template>
      <template #right>
        <span class="end">结束</span>
      </template>
    </van-nav-bar>
    <!-- 播放区域 -->
    <div
      v-if="memberList.length > 0"
      class="container"
      :class="[
        groupCall ? 'container-' + layout : 'container-C2C',
        memberList.length < 2 && yardmanType === '2' ? 'container-remote-only' : '',
        memberList.length < 2 && yardmanType === '1' ? 'container-C2C' : '',
      ]"
      @click="showLayout = false"
    >
      <!-- 本地流播放区域 -->
      <div v-show="yardmanType === '1'" id="localStream" class="stream-content">
        <avatar class="avatar" v-show="type === 'audio' || isMutedVideo" :size="60">
          <div class="peer-name">{{ currentUserProfile.nick }}</div>
        </avatar>
        <div class="info">
          <span class="name">{{ currentUserProfile.nick }}</span>
          <i class="micro-status" :class="'micro-status-' + (isMutedAudio ? 'off' : 'on')"></i>
        </div>
      </div>
      <!-- 远端流区域 -->
      <div
        v-for="item in memberListSort"
        :key="item.id"
        :id="item.tencentUserId"
        class="stream-content"
        :class="item.state ? 'stream-content-' + item.state : 'stream-content-CONNECTING'"
      >
        <!-- 头像，语音模式下和拨号中才显示 -->
        <avatar class="avatar" v-if="type === 'audio'" v-show="item.state === 'CONNECTED'" :size="60">
          <div class="peer-name">{{ item.name }}</div>
        </avatar>
        <div class="info">
          <!-- 被调度人昵称 -->
          <span class="name">{{ item.name }}</span>
          <!-- 被调度人语音流状态 -->
          <i
            class="micro-status"
            :class="
              'micro-status-' + (remoteStreamList.find((x) => x.getUserId() === item.tencentUserId)?.hasAudio() ? 'on' : 'off')
            "
          ></i>
          <!-- !!!被调度人举手 这里一定要用 v-show  -->
          <i class="hand-up" v-show="item.action === 'handUp' || item.action === 'cheese'"></i>
        </div>
      </div>
    </div>
    <div class="footer">
      <!-- 禁音 -->
      <div :class="!isMutedAudio ? 'micOn' : 'micOff'" @click="handleMuteAudio">
        <i class="icon"></i>
        <span class="name">{{ !isMutedAudio ? "静音" : "解除禁音" }}</span>
      </div>
      <!-- 关闭视频 -->
      <div
        v-if="type === 'video' && yardmanType === '1'"
        :class="!isMutedVideo ? 'videoOn' : 'videoOff'"
        @click="handleMuteVideo"
      >
        <i class="icon"></i>
        <span class="name">{{ !isMutedVideo ? "关闭视频" : "开启视频" }}</span>
      </div>
      <!-- 切换布局 -->
      <div v-if="groupCall" class="layout" @click="showLayout = true">
        <i class="icon"></i>
        <span class="name">切换布局</span>
      </div>
      <!-- 成员 -->
      <div v-if="groupCall" class="members" @click="showMembers">
        <i class="icon"></i>
        <span class="name">成员</span>
      </div>
    </div>
    <van-radio-group v-show="showLayout" class="layout-box" v-model="layout">
      <div class="layout-box-type">
        <div class="layout-type-img layout-type-img-3" @click="layout = 3"></div>
        <van-radio :name="3" :disabled="memberList.length > 3">三宫格</van-radio>
      </div>
      <div class="layout-box-type">
        <div class="layout-type-img layout-type-img-6" @click="layout = 6"></div>
        <van-radio :name="6" :disabled="memberList.length > 6">六宫格</van-radio>
      </div>
      <div class="layout-box-type">
        <div class="layout-type-img layout-type-img-9" @click="layout = 9"></div>
        <van-radio :name="9">九宫格</van-radio>
      </div>
    </van-radio-group>
  </van-popup>
</template>

<script>
import { NavBar, Popup, RadioGroup, Radio, Icon, Toast } from "vant";
import rtc from "@/components/mixins/rtc";
import { getRooms, leave } from "@/api/room-controller";
import { exitRoom, sendVideoRoomMsg } from "@/api/bcxin/identify";
import Avatar from "@components/avatar.vue";
import { mapState } from "vuex";
import dayjs from "dayjs";
import duration from "dayjs/plugin/duration";
dayjs.extend(duration);

export default {
  name: "CallLayer",
  components: {
    Avatar,
    [Popup.name]: Popup,
    [NavBar.name]: NavBar,
    [RadioGroup.name]: RadioGroup,
    [Radio.name]: Radio,
    [Icon.name]: Icon,
    [Toast.name]: Toast,
  },
  mixins: [rtc],
  props: {
    visible: Boolean,
    groupCall: Boolean, // 是否多人模式
    memberList: {
      type: Array,
      default() {
        return [];
      },
    },
    allMembers: {
      // 除调度人外所有可选的参与者
      type: Array,
      default() {
        return [];
      },
    },
    type: {
      type: String,
      default: "video",
      validate: (value) => {
        return ["video", "audio"].includes(value);
      },
    },
    audio: {
      type: Boolean,
      default: true,
    },
    video: {
      type: Boolean,
      default: true,
    },
    yardmanType: {
      // 调度类型：1视频调度 2 视频上拉：除了视频上拉传2，其他音频调度与视频调度都传1
      type: String,
      default: "1",
    },
  },
  data() {
    return {
      dialling: false, // 是否拨打电话中
      calling: false, // 是否通话中
      isDialled: false, // 是否被呼叫
      currentDatetime: "00:00",
      startTime: null,
      timer: null,
      layout: 3,
      showLayout: false,
      diallingTime: 0, // 1V1拨号倒计时
      diallingTimer: null, // 1V1拨号倒计时定时器
      roomId: "",
      allMembersTimer: null,
    };
  },
  computed: {
    ...mapState({
      currentUserProfile: (state) => state.user.currentUserProfile,
      userID: (state) => state.user.userID,
      userSig: (state) => state.user.userSig,
      sdkAppID: (state) => state.user.sdkAppID,
      sysUserInfo: (state) => state.user.sysUserInfo,
    }),
    title() {
      return "紧急呼叫中";
    },
    showCalling: {
      get() {
        return this.dialling || this.calling || this.isDialled;
      },
      set(value) {
        this.dialling = value;
        this.calling = value;
        this.isDialled = value;
      },
    },
    memberListSort() {
      return [...this.memberList].sort((a, b) => {
        return a?.state?.localeCompare(b?.state);
      });
    },
  },
  watch: {
    memberList: {
      handler(value) {
        if (value.length > 0) {
          this.layout = 3;
          if (value.length >= 3) {
            this.layout = 6;
            if (value.length >= 6) {
              this.layout = 9;
            }
          }
          /**
           * 调度通讯中以下几种情况，调度窗口直接关闭：
           * 第一、全员接听后都挂断
           * 第二、全员都被移除
           * 第三、全员全部超时未接听
           * 第四、调度窗口中，只剩调度员一个
           */
          const offlineMembers = [...value].filter((x) => x.state === "DISCONNECTED").length;
          console.log("offline members", offlineMembers, value.length);
          if (offlineMembers >= value.length && (this.calling || this.dialling)) {
            this.onClose();
          }
        }
      },
      deep: true,
      immediate: true,
    },
    /**
     * @一对一被调度方没有接的话1分钟后调度方直接结束
     * @param value
     */
    diallingTime(value) {
      if (value && value >= 60 /* && process.env.VUE_APP_ENV !== "development" */) {
        this.onClose();
      }
    },
  },
  methods: {
    onOpen() {
      this.startTime = new Date();
      this.setTimer();
    },
    onClose() {
      this.showCalling = false;
    },
    handleLeave() {
      this.endDialingTimeCounting();
      this.endMemberTimer();
      this.endCurrentTimer();
      this.leave().then(async () => {
        try {
          await exitRoom({ roomNo: this.roomId });
          this.close();
        } catch (error) {
          console.error("leave room error", error);
          this.addFailedLog(`Leave room failed. Error: ${error.message}`);
          // this.reportFailedEvent("leaveRoom", error);
          throw error;
        }
      });
    },
    close() {
      leave(this.roomId).then((res) => {
        console.log(res);
        const memberList = this.memberList.map((x) => {
          return {
            ...x,
            state: "CONNECTING",
            action: "",
            timer: 0,
            timeout: false,
            beKickOut: false,
            hangup: false,
          };
        });
        this.$emit("update:memberList", memberList);
        // this.$store.commit("TOGGLE_DISPATCHING", false);
        this.$store.commit("SET_ROOM_ID", null);
        this.$emit("close");
      });
    },
    timeFormat(hours, minutes, seconds) {
      if (hours > 0) {
        if (hours < 10) {
          hours = "0" + hours;
        }
        if (minutes < 10) {
          minutes = "0" + minutes;
        }
        if (seconds < 10) {
          seconds = "0" + seconds;
        }
        return hours + ":" + minutes + ":" + seconds;
      } else {
        if (minutes > 0) {
          if (minutes < 10) {
            minutes = "0" + minutes;
          }
          if (seconds < 10) {
            seconds = "0" + seconds;
          }
          return minutes + ":" + seconds;
        } else {
          if (seconds < 10) {
            seconds = "0" + seconds;
          }
          return "00:" + seconds;
        }
      }
    },
    setTimer() {
      this.timer = setTimeout(() => {
        const x = dayjs();
        const y = dayjs(this.startTime);
        const currentHour = dayjs.duration(x.diff(y)).get("hours");
        const currentMin = dayjs.duration(x.diff(y)).get("minutes");
        const currentSecond = dayjs.duration(x.diff(y)).get("seconds");
        this.currentDatetime = this.timeFormat(currentHour, currentMin, currentSecond);
        this.setTimer();
      }, 1000);
    },
    /**
     * @后台拨号接口
     * @param roomId
     * @param MemberList
     * @param UseList
     */
    sendRoomMessage(roomId, MemberList, UseList) {
      const userInfo = localStorage.getItem("userInfo");
      if (userInfo) {
        const user = JSON.parse(userInfo);
        const params = {
          RoomNo: roomId, //房间
          type: this.type, //video or audio
          MemberList,
          name: user.name, //调度者名称
          Yardman_Name: user.tencentUserId, //调度者名称
          Yardman_Task_Name: "个人调度", //调度任务名称
          Yardman_Type: this.yardmanType, //调度类型：1视频调度 2 视频上拉：除了视频上拉传2，其他音频调度与视频调度都传1
          yardmanType: this.yardmanType, //调度类型：1视频调度 2 视频上拉：除了视频上拉传2，其他音频调度与视频调度都传1
          Yardman_Task_Explain: "任务说明", //调度任务说明，非必填
          // Transcriber: "", //录制人员cid,多个逗号隔开，非必填
          Originator: user.tencentUserId + ";" + user.tencentUserId, //发起人cid;useid
          //被调度视频人员,跟MemberList一一对应uid;employeeid;organizationId;name;type,...
          UseList,
          ComId: user.organizationId, //调度者公司id
        };
        // 后端去给被调度者的app拨号
        sendVideoRoomMsg(params).then((res) => {
          console.log(res);
        });
      }
    },
    /**
     * @1v1或者视频上拉时，计算拨号时长
     */
    startDialingTimeCounting() {
      if (this.yardmanType === "2" || this.memberList.length < 2) {
        this.diallingTimer = setInterval(() => {
          this.diallingTime += 1;
        }, 1000);
      }
    },
    /**
     * @结束拨号计时
     */
    endDialingTimeCounting() {
      if (this.diallingTimer) {
        clearInterval(this.diallingTimer);
        this.diallingTimer = null;
        this.diallingTime = 0;
      }
    },
    /**
     * @结束成员计时
     */
    endMemberTimer() {
      if (this.allMembersTimer) {
        clearInterval(this.allMembersTimer);
        this.allMembersTimer = null;
      }
    },
    /**
     * @结束显示计时
     */
    endCurrentTimer() {
      this.currentDatetime = "00:00";
      if (this.timer) {
        clearTimeout(this.timer);
        this.timer = null;
      }
    },
    async videoCalling() {
      const userInfo = localStorage.getItem("userInfo");
      let roomUsers = [];
      if (userInfo) {
        const user = JSON.parse(userInfo);
        console.log(user);
        roomUsers.push({
          employeeId: user.employeeId,
          organizationId: user.organizationId,
          tencentUserId: user.tencentUserId,
          securityStationId: "",
          superviseDepartId: "",
          sponsor: true,
        });
        getRooms({
          roomUsers: roomUsers.concat(
            this.memberList.map((x) => {
              return {
                employeeId: x.id,
                organizationId: x.organizationId,
                tencentUserId: x.tencentUserId,
                securityStationId: x.securityStationId,
                superviseDepartId: x.superviseDepartId,
                sponsor: false,
              };
            })
          ),
          communicatedType: this.type === "video" ? "Video" : "Audio", //新增传参
          yardmanType: this.yardmanType, //调度类型：1视频调度 2 视频上拉：除了视频上拉传2，其他音频调度与视频调度都传1
          deskType: this.$route.query.stationType === "TemporarySecurity" ? "TemporarySecurity" : "Normal",
        })
          .then(async (res) => {
            const { id, roomUsers } = res;
            console.log(id);
            if (id <= 0) {
              this.addFailedLog(`被调度人所在企业联动值不足, 无法进行调度。`);
              return false;
            } else {
              this.dialling = true; // 拨号中
              // 1v1或者视频上拉时，计算拨号时长
              this.startDialingTimeCounting();
              // 分别对所有参会人计时
              this.setAllMembersTimer();
              // 初始化客户端
              await this.initClient();
              this.roomId = id;
              this.$store.commit("SET_ROOM_ID", this.roomId);
              // 加入房间
              await this.join();
              await this.initLocalStream({
                audio: this.audio,
                video: this.video,
              }); // 初始话本地流
              await this.playLocalStream(); // 播放本地流
              await this.publish(); // 发布本地流
              // let uidList = []//视频人员uid
              // const { mobilePhone, id, organizationId, deviceNumber, tencentUserId, name, cid, securityStationId, superviseDepartId } = item;
              // const item_cid = cid || tencentUserId
              // uidList.push(`${tencentUserId};${id};${organizationId};${name};${type}`)
              console.log("~~~~~user", user);
              console.log("~~~~~", this.memberList);
              const memberList = roomUsers
                .filter((item) => item.cid && item.sponsor === false)
                .map((x) => {
                  return x.cid;
                })
                .join(",");
              const UseList = this.memberList
                .map((x) => {
                  const { id, organizationId, tencentUserId, name } = x;
                  // const item_cid = cid || tencentUserId
                  // uidList.push(`${tencentUserId};${id};${organizationId};${name};${type}`)
                  return `${tencentUserId};${id};${organizationId};${name};${this.type}`;
                })
                .join(",");
              this.sendRoomMessage(this.roomId, memberList, UseList);
            }
          })
          .catch(({ response }) => {
            console.log(response);
            this.addFailedLog(`${response.data.message}`);
          });
      }
    },
    audioCalling() {},
    /**
     * @显示用户名的提示
     * @param id
     * @param message
     * @param err
     */
    userLog(id, message, err = false) {
      const user = this.memberList.find((member) => member.tencentUserId === id);
      if (user) {
        console.log(user);
        if (err) {
          this.addFailedLog(`[${user.name}] ${message}`);
        } else {
          this.addSuccessLog(`[${user.name}] ${message}`);
        }
      }
    },
    addSuccessLog(message) {
      console.log(message);
      Toast.success(message);
      // Notify({ type: 'success', message });
    },
    addFailedLog(message) {
      // Notify({ type: "danger", message });
      Toast.fail(message);
    },
    handleMuteAudio() {
      if (this.isMutedAudio) {
        this.unmuteAudio();
      } else {
        this.muteAudio();
      }
    },
    handleMuteVideo() {
      if (this.isMutedVideo) {
        this.unmuteVideo();
      } else {
        this.muteVideo();
      }
    },
    showMembers() {
      // this.close();
      this.$emit("showMembers");
    },
    setAllMembersTimer() {
      this.allMembersTimer = setInterval(() => {
        this.memberList.forEach((member) => {
          const hasKey = Object.prototype.hasOwnProperty.call(member, "timer");
          const beKickOut = member.beKickOut;
          if (!hasKey || beKickOut || member.state === "CONNECTED") {
            member.timer = 0;
          } else {
            console.log("现在的人员状态是。。", member.state);
            if (member.timer < 60 && member.state === "CONNECTING") {
              member.timer++;
              member.timeout = false;
            } else {
              console.log("进入了超时判断", member.state);
              if (member.state !== "DISCONNECTED") {
                member.timer = 0;
                member.timeout = true;
                member.state = "DISCONNECTED";
              }
            }
          }
        });
        this.$emit("update:memberList", JSON.parse(JSON.stringify(this.memberList)));
        console.log("%c memberList", "background: #00cc00; color: #fff; border-radius: 3px;padding:2px 5px", this.memberList);
      }, 1000);
    },
  },
  mounted() {
    this.$bus.$on("video-call", this.videoCalling); // 发起通话
    this.$bus.$on("audio-call", this.audioCalling); // 发起通话
  },
  beforeDestroy() {
    if (this.timer) {
      clearTimeout(this.timer);
      this.timer = null;
    }
    this.$bus.$off("video-call", this.videoCalling);
    this.$bus.$off("audio-call", this.audioCalling); // 发起通话
  },
};
</script>

<style scoped lang="less">
@nav-bar-background-color: #1e263c;
@nav-bar-height: 58px;
.van-hairline--bottom::after {
  border-bottom-width: 0;
}
.call-nav-bar {
  background: #1e263c;
  height: 58px;
  ::v-deep .van-nav-bar__content {
    height: 100%;
  }
  .title {
    display: flex;
    flex-direction: column;
    align-items: center;

    .name {
      font-size: 14px;
      font-family: PingFang SC-Regular, PingFang SC;
      font-weight: 400;
      color: #ffffff;
      line-height: 14px;
      margin-bottom: 8px;
    }
    .timer {
      font-size: 10px;
      font-family: PingFang SC-Regular, PingFang SC;
      font-weight: 400;
      color: #ffffff;
      line-height: 10px;
    }
  }
  .end {
    font-size: 16px;
    font-family: PingFang SC-Regular, PingFang SC;
    font-weight: 400;
    color: #f74c33;
    line-height: 16px;
  }
}
.container {
  width: 100%;
  height: calc(100vh - 85px - 58px);
  background: #0e1425;
  display: grid;
  grid-auto-rows: 100%;
  overflow: scroll;
  &-3 {
    //划容器为三个1fr的列
    grid-template-columns: 1fr 1fr 1fr;
  }
  &-6 {
    grid-template-columns: repeat(3, 1fr);
    //grid-template-rows: repeat(2, 1fr);
    grid-auto-rows: 50%;
  }
  &-9 {
    grid-template-columns: repeat(3, 1fr);
    //grid-template-rows: repeat(3, 1fr);
    grid-auto-rows: 33.3%;
  }
  &-remote-only {
    grid-template-columns: 1fr;
  }
  &-C2C {
    grid-template-rows: 50% 50%;
  }
  .stream-content {
    background: #2b2b2b;
    position: relative;
    width: 100%;
    &-CONNECTING {
      &::before {
        content: " ";
        display: block;
        position: absolute;
        top: 50%;
        left: 50%;
        width: 80px;
        height: 80px;
        background: url("~@/assets/images/conversation/呼叫中、未接听、已挂断图标/呼叫中.png") no-repeat;
        background-size: 100% 100%;
        transform: translate(-50%, -50%);
      }
    }
    &-DISCONNECTED {
      &::before {
        content: " ";
        display: block;
        position: absolute;
        top: 50%;
        left: 50%;
        width: 80px;
        height: 80px;
        background: url("~@/assets/images/conversation/呼叫中、未接听、已挂断图标/已挂断.png") no-repeat;
        background-size: 100% 100%;
        transform: translate(-50%, -50%);
      }
    }
    //height: 691px;
    .info {
      //width: 58px;
      height: 28px;
      position: absolute;
      top: 0;
      left: 0;
      z-index: 2;
      display: flex;
      justify-content: center;
      align-items: center;
      background: rgba(0, 0, 0, 0.6);
      padding: 0 6px;
      .name {
        font-size: 14px;
        font-weight: 400;
        color: rgba(255, 255, 255, 0.85);
      }
      .micro-status {
        display: block;
        width: 16px;
        height: 16px;
        margin-left: 4px;
        &-on {
          background: url("~@/assets/images/conversation/语音开启.png") no-repeat;
          background-size: 100% 100%;
        }
        &-off {
          background: url("~@/assets/images/conversation/语音关闭.png") no-repeat;
          background-size: 100% 100%;
        }
      }
      .hand-up {
        display: block;
        width: 16px;
        height: 16px;
        margin-left: 4px;
        background: url("~@/assets/images/conversation/移动端举手.png") no-repeat;
        background-size: 100% 100%;
      }
    }
    .avatar {
      position: absolute;
      top: 50%;
      left: 50%;
      transform: translate(-50%, -50%);
      z-index: 2;
      .peer-name {
        width: 100%;
        height: 100%;
        //border-radius: 50%;
        overflow: hidden;
        margin-right: 16px;
        background: #0e71ff;
        font-size: 16px;
        font-weight: 400;
        color: #ffffff;
        display: flex;
        align-items: center;
        justify-content: center;
      }
    }
  }
}
.footer {
  width: 100%;
  height: 85px;
  background: #1e263c;
  display: flex;
  justify-content: center;
  align-items: center;
}
.layout,
.accept,
.refuse,
.members,
.videoOn,
.videoOff,
.micOn,
.micOff {
  width: 70px;
  height: 47px;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  box-sizing: border-box;
  //border-radius: 50%;
  cursor: pointer;
  text-align: center;
  margin-left: 5px;
  position: relative;
  &:hover {
    background: rgba(255, 255, 255, 0.1993);
  }
  .icon {
    width: 18px;
    height: 18px;
  }
  .name {
    font-size: 12px;
    font-weight: 400;
    color: #ffffff;
    line-height: 14px;
    width: 70px;
  }
  .layout-picker {
    display: flex;
    justify-content: space-between;
    align-items: center;
    width: 340px;
    height: 125px;
    background: #333438;
    border-radius: 4px 4px 4px 4px;
    padding: 0 24px;
    position: absolute;
    bottom: 50px;
    //left: -10px;
    .layout-type {
      width: 76px;
      height: 74px;
      display: flex;
      flex-direction: column;
      align-items: center;
      justify-content: space-between;

      .layout-type-img {
        width: 76px;
        height: 52px;
        margin-bottom: 8px;
        &-3 {
          background: url("~@/assets/images/conversation/三宫格.png") no-repeat;
          background-size: 100% 100%;
        }
        &-6 {
          background: url("~@/assets/images/conversation/六宫格.png") no-repeat;
          background-size: 100% 100%;
        }
        &-9 {
          background: url("~@/assets/images/conversation/9宫格.png") no-repeat;
          background-size: 100% 100%;
        }
      }
    }
  }
}
.accept {
  background-size: 60%;
  background: #0ac160 url("~@/assets/images/conversation/call.png") no-repeat;
}

.layout {
  .icon {
    background: url("~@/assets/images/conversation/switch.png") no-repeat;
    background-size: 100% 100%;
  }
}

.refuse {
  .icon {
    background: url("~@/assets/images/conversation/close.png") no-repeat;
    background-size: 100% 100%;
  }
}

.videoOn {
  .icon {
    background: url("~@/assets/images/conversation/视频.png") no-repeat;
    background-size: 100% 100%;
  }
}

.videoOff {
  .icon {
    background: url("~@/assets/images/conversation/开启视频.png") no-repeat;
    background-size: 100% 100%;
  }
}

.micOn {
  .icon {
    background: url("~@/assets/images/conversation/静音.png") no-repeat;
    background-size: 100% 100%;
  }
}

.micOff {
  .icon {
    background: url("~@/assets/images/conversation/解除静音.png") no-repeat;
    background-size: 100% 100%;
  }
}

.members {
  .icon {
    background: url("~@/assets/images/conversation/成员-2.png") no-repeat;
    background-size: 100% 100%;
  }
}

.layout-box {
  width: 340px;
  height: 125px;
  background: #333438;
  border-radius: 4px;
  position: absolute;
  bottom: 93px;
  left: 50%;
  transform: translate(-50%, 0);
  display: flex;
  justify-content: space-evenly;
  align-items: center;
  &-type {
    display: flex;
    flex-direction: column;
    height: 76px;
    width: 76px;
    justify-content: space-between;
    .layout-type-img {
      width: 100%;
      height: 52px;
      //margin-bottom: 8px;
      &-3 {
        background: url("~@/assets/images/conversation/三宫格.png") no-repeat;
        background-size: 100% 100%;
      }
      &-6 {
        background: url("~@/assets/images/conversation/六宫格.png") no-repeat;
        background-size: 100% 100%;
      }
      &-9 {
        background: url("~@/assets/images/conversation/9宫格.png") no-repeat;
        background-size: 100% 100%;
      }
    }
    ::v-deep .van-radio__label {
      font-size: 12px;
      font-family: PingFang SC-Regular, PingFang SC;
      font-weight: 400;
      color: rgba(255, 255, 255, 0.85);
      line-height: 14px;
      margin-left: 8px;
    }
  }
}
</style>
